@@ -8,7 +8,7 @@ from pathlib import Path
 from sys import exit, stderr
 from typing import List, Optional
 
-from ycontract import out_contract
+from ycontract import contract
 
 from exclock.sound_player import Player
 from exclock.util import (
@@ -23,7 +23,7 @@ from exclock.util import (
 )
 
 
-@out_contract(lambda res: res is None or res >= 0)
+@contract(returns=lambda res: res is None or res >= 0)
 def get_spend_sec(time_: str) -> Optional[int]:
     if is_specific_time_str(time_):
         now_ = datetime.now()
